# nanosite
nanosite is a static site generator in Python. It's designed to cut through all of the boilerplate and leave the entire structure of your site as flexible as possible. Feedback and pull requests are welcome.

For full documentation and a tutorial, check out nanosite's website: [nanosite](http://wanganzhou.com/nanosite).

Here's a website made with nanosite: [wanganzhou.com](http://wanganzhou.com/).

## Features
* Write your content in simple [Markdown](http://daringfireball.net/projects/markdown/) format, or templated HTML.
* Create a blog or static pages or a combination of both.
* Built-in server &mdash; develop your site live.
* Bare-bones and extremely flexible.

## How to Install
nanosite uses Python 3. Download the repo and run setup.py install:

    python setup.py install

## How to Use
To start a new site, simply run `nanosite` at the terminal, in the directory you want the site to be in. Follow the prompts to generate a blank site. Run `nanosite` again to serve your site, which you can view at http://localhost:8000/.

Try `nanosite import blog` for a ready-made blog template featuring posts, static pages and an archive.

Check out the [tutorial](http://wanganzhou.com/nanosite/tutorial.html) and [documentation](http://wanganzhou.com/nanosite/doc).
